exitImageContainerDecoration property
Decoration applied to the container surrounding the exit image (e.g., border radius, background color, shadows).
Implementation
final Decoration? exitImageContainerDecoration;
Decoration applied to the container surrounding the exit image (e.g., border radius, background color, shadows).
final Decoration? exitImageContainerDecoration;